\name{calc_parameters}
\Rdversion{1.0}
\alias{calc_parameters}
\title{Calculate Parameter Estimates (calc_parameters)}
\description{
An internal function called by the \code{tmle} function to calculate the additive treatment effect, and if the outcome is binary, also the relative risk and odds ratio parameters.  P-values and 95\% confidence intervals are also calculated (on the log scale for RR and OR).
}
\usage{
calc_parameters(Y, A, Delta, g1W, g0W, Q, mu1, mu0, id, family)
}
\arguments{
  \item{Y}{continuous or binary outcome variable}
  \item{A}{binary treatment indicator, \code{1} - treatment, \code{0} - control}
  \item{Delta}{indicator of missing outcome. \code{1} - observed, \code{0} - missing}
  \item{g1W}{censoring mechanism estimates, \eqn{P(A=1|W)*P(Delta=1|A,W)}}
  \item{g0W}{censoring mechanism estimates, \eqn{P(A=0|W)*P(Delta=1|A,W)}}
  \item{Q}{a 3-column matrix \code{(Q(A,W), Q(1,W), Q(0,W))}}
  \item{mu1}{targeted estimate of \eqn{E(Y|A=1,W)}}
  \item{mu0}{targeted estimate of \eqn{E(Y|A=0,W)}}
  \item{id}{subject identifier}
  \item{family}{family specification for regressions, generally \sQuote{gaussian} for continuous oucomes, \sQuote{binomial} for binary outcomes}
}
\value{
  \item{ATE}{additive treatment effect estimate, variance, p-value, 95\% confidence interval}
  \item{RR}{relative risk estimate, p-value, 95\% confidence interval, log(RR), variance(log(RR))}
  \item{OR}{odds ratio estimate, p-value, 95\% confidence interval, log(OR), variance(log(OR))}
}

\author{Susan Gruber}

\seealso{
\code{\link{tmle}},
\code{\link{estimate_Q}},
\code{\link{estimate_g}},
\code{\link[DSA]{DSA}},
\code{\link[SuperLearner]{SuperLearner}}
}
