\name{tmle}
\Rdversion{1.0}
\alias{tmle}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Targeted Maximum Likelihood Estimation}
\description{
Carries out targeted maximum likelihood estimation of marginal additive treatment effect of a binary point treatment on an outcome.  For binary outcomes risk ratio and odds ratio estimates are also reported. The \code{tmle} function is minimally called with arguments \code{(Y,A,W)}, where  \code{Y} is a continuous or binary outcome variable, \code{A} is a binary treatment variable, (\code{A=1} for treatment, \code{A=0} for control), and \code{W} is a matrix or dataframe of baseline covariates. Missingness in the outcome is accounted for in the estimation procedure if missingness indicator \code{Delta} is 0 for some observations.  Repeated measures can be identified using the \code{id} argument.}
\usage{
tmle(Y, A, W, Delta = rep(1,length(Y)), Q = NULL, Qform = NULL, Qbounds = NULL, g1W = NULL, 
     gform = NULL, gbound = 0.025,  pDelta1 = NULL, g_Deltaform = NULL, Q.SL.library = NULL, 
     cvQinit = FALSE, g.SL.library = c("SL.glm", "SL.step", "SL.knn", "SL.DSA.2"),
     family = "gaussian", fluctuation = "logistic", alpha = 0.995, id=1:length(Y), verbose = FALSE)
}
\arguments{
  \item{Y}{continuous or binary outcome variable}
  \item{A}{binary treatment indicator, \code{1} - treatment, \code{0} - control}
  \item{W}{vector, matrix, or dataframe containing baseline covariates}
  \item{Delta}{indicator of missing outcome or treatment assignment.  \code{1} - observed, \code{0} - missing}
  \item{Q}{\eqn{E(Y|A,W)}, optional \eqn{nx2} matrix of initial values for \eqn{Q} portion of the likelihood, \eqn{(E(Y|A=0,W), E(Y|A=1,W))}}
  \item{Qform}{optional regression formula for estimation of \eqn{E(Y|A, W)}, suitable for call to \code{glm}}
  \item{Qbounds}{vector of upper and lower bounds on \code{Y} and predicted values for initial \code{Q}}
  \item{g1W}{optional vector of conditional treatment assingment probabilities, \eqn{P(A=1|W)}}
  \item{gform}{optional regression formula of the form \code{A~W}, if specified this overrides the call to \code{SuperLearner}}
  \item{gbound}{value between (0,1) for truncation of predicted probabilities. See \code{Details} section for more information.}
  \item{pDelta1}{optional vector of probabilities for missingness mechanism \eqn{P(Delta=1|A,W)}}
  \item{g_Deltaform}{optional regression formula of the form \code{Delta~A+W}, if specified this overrides the call to \code{SuperLearner}}
  \item{Q.SL.library}{optional vector of prediction algorithms to use for \code{SuperLearner} estimation of initial \code{Q}. }
  \item{cvQinit}{logical, if \code{TRUE}, estimates cross-validated predicted values using discrete super learning, default=\code{FALSE}}
  \item{g.SL.library}{optional vector of prediction algorithms to use for \code{SuperLearner} estimation of \code{g1W} or \code{pDelta1}. }
  \item{family}{family specification for working regression models, generally \sQuote{gaussian} for continuous outcomes (default), \sQuote{binomial} for binary outcomes.}
  \item{fluctuation}{\sQuote{logistic} (default), or \sQuote{linear}}
  \item{alpha}{used to keep predicted initial values bounded away from (0,1) for logistic fluctuation}
  \item{id}{optional subject identifier}
  \item{verbose}{status messages printed if set to \code{TRUE} (default=\code{FALSE})}
}
\details{
 \code{gbounds} defaults to (0.025, 0.975) for \eqn{P(A=1|W)}*{P(Delta=1|A,W)}.  To specify symmetrical truncation levels, only one value has to be provided.

 \code{Q.SL.library} defaults to (\sQuote{SL.glm}, \sQuote{SL.step}, \sQuote{SL.DSA.2}) when family=\sQuote{gaussian}, (\sQuote{SL.glm}, \sQuote{SL.step}, \sQuote{SL.knn}, \sQuote{SL.DSA.2}) when family = \sQuote{binomial}

 \code{g.SL.library} Defaults to (\sQuote{SL.glm}, \sQuote{SL.step}, \sQuote{SL.knn}, \sQuote{SL.DSA.2})

 See \code{SuperLearner} help files for further information.
}
\value{
  \item{estimates}{list with elements ATE (additive treatment effect), RR (relative risk), OR (odds ratio). Each element in the estimates of these is itself a list containing 
 \itemize{
  \item psi - parameter estimate 
  \item pvalue - two-sided p-value
  \item CI - 95\% confidence interval
  \item var.psi - Influence-curve based variance of estimate (ATE parameter only)
  \item log.psi - Parameter estimate on log scale (RR and OR parameters)
  \item var.log.psi - Influence-curve based variance of estimate on log scale (RR and OR parameters)
  }}
  \item{Qinit}{initial estimate of \code{Q}. \code{Qinit$coef} are the coefficients for a \code{glm} model for \code{Q}, if applicable.  \code{Qinit$Q} is an \eqn{nx3} matrix, where \code{n} is the number of observations.  Columns contain targeted predicted values for \code{Q(A,W),Q(1,W),Q(0,W)}, respectively.  \code{Qinit$type} is method for estimating \code{Q}}
  \item{g}{treatment mechanism estimate. A list with three items: \code{g$g1W} contains estimates of \eqn{P(A=1|W)} for each observation, \code{g$coef} the coefficients for the model for \eqn{g} when \code{glm} used, \code{g$type} estimation procedure}
  \item{g_Delta}{missingness mechanism estimate. A list with three items: \code{g_Delta$g1W} contains values of \eqn{P(A=1|W)} for each observation, \code{g_Delta$coef} the coefficients for the model for \eqn{g} when \code{glm} used, \code{g_Delta$type} estimation procedure}
}
\references{
1. Gruber, S. and van der Laan, M.J. (2009), {Targeted Maximum Likelihood Estimation: A Gentle Introduction}. \emph{U.C. Berkeley Division of Biostatistics Working Paper Series}.  Working Paper 252.  \url{http://www.bepress.com/ucbbiostat/paper252}

2. Gruber, S. and van der Laan, M.J.  (2010), {A Targeted Maximum Likelihood Estimator of a Causal Effect on a Bounded Continuous Outcome}. \emph{The International Journal of Biostatistics}, 6(1), 2010.

3. van der Laan, M.J. and Rubin, D. (2006), {Targeted Maximum Likelihood Learning}. \emph{The International Journal of Biostatistics}, 2(1). \url{http://www.bepress.com/ijb/vol2/iss1/11/}

4. van der Laan, M.J., Rose, S., and Gruber,S., editors, (2009) {Readings in Targeted Maximum Likelihood Estimation} . \emph{U.C. Berkeley Division of Biostatistics Working Paper Series}.  Working Paper 254. \url{http://www.bepress.com/ucbbiostat/paper254}
}

\author{Susan Gruber \email{sgruber@berkeley.edu}, in collaboration with Mark van der Laan.}


\seealso{
\code{\link{summary.tmle}},
\code{\link{estimate_Q}},
\code{\link{estimate_g}},
\code{\link{calc_parameters}},
\code{\link[SuperLearner]{SuperLearner}}
\code{\link[DSA]{DSA}}
}
\examples{
library(tmle)

# generate data
  n <- 500
  W <- matrix(rnorm(n*3), ncol=3)
  A <- rbinom(n,1, 1/(1+exp(-(.1*W[,1] - .1*W[,2] + .5*W[,3]))))
  Y <- A + 2*W[,1] + W[,3] + W[,2]^2 + rnorm(n)
  colnames(W) <- paste("W",1:3, sep="")

# Example 1. Simplest function invocation 
# SuperLearner called to estimate Q, g
# Delta defaults to 1 for all observations
#   
  result1 <- tmle(Y,A,W)
  summary(result1)

# Example 2: 
# SuperLearner called to estimate Q with library including glm,
# DSA with main terms only, and ridge regression
# known treatment mechanism, g1W, is user supplied 
# 
  A.ex2 <- rbinom(n,1,.5)
  Y.ex2 <- A.ex2 + 2*W[,1] + W[,3] + W[,2]^2 + rnorm(n)
  SL.library <- c("SL.glm", "SL.DSA", "SL.ridge")
  result2 <- tmle(Y=Y.ex2,A=A.ex2,W, g1W =rep(.5, length(Y)),
		  Q.SL.library=SL.library)
  summary(result2)

# Example 3: 
# User-supplied (misspecified) model for Q, 
# Super learner called to estimate g, g_Delta
# approx. 20% missing at random

  Delta <- rbinom(n, 1, 1/(1+exp(-(1.7-1*W[,1]))))
  result3 <- tmle(Y,A,W, Delta=Delta, Qform="Y~A+W1+W2+W3")
  summary(result3)
}
